==> heptapod-rails-0.25.2.tar.gz: heptapod-rails-0.25.2/workhorse/internal/hg/hg-proxy_test.go <==
package hg

import (
	"net/http"
	"testing"

	"github.com/stretchr/testify/assert"
	"gitlab.com/gitlab-org/gitaly/v14/proto/go/gitalypb"

	"gitlab.com/gitlab-org/gitlab/workhorse/internal/api"
)

func TestAlterRequest(t *testing.T) {
	type testcase struct {
		native_input    bool
		native_expected string
	}

	testcases := []testcase{
		{native_expected: "false"},
		{native_input: false, native_expected: "false"},
		{native_input: true, native_expected: "true"},
	}

	for _, tc := range testcases {
		api_resp := api.Response{
			GL_ID:                   "user-17",
			GL_USERNAME:             "testgr",
			GL_REPOSITORY:           "project-23",
			HG_ACCESS_LEVEL:         "publish",
			HEPTAPOD_USERINFO_EMAIL: "testgr@heptapod.test",
			HEPTAPOD_USERINFO_NAME:  "Test GR",
			HEPTAPOD_HG_NATIVE:      tc.native_input,
			Repository: gitalypb.Repository{
				StorageName:   "default",
				RelativePath:  "foo/bar.git",
				GlProjectPath: "path/to/my/repository",
			},
		}
		http_req, _ := http.NewRequest("GET",
			"http://heptapod.example/my/repo?cmd=capabilities", nil)
		alterRequest(http_req, &api_resp)

		// the path part of the backend request is derived from the Git
		// repo RelativePath
		assert.Equal(t, http_req.URL.Path, "foo/bar.hg")

		header := http_req.Header
		assert.Equal(t, header.Get(PERMISSION_HEADER), "heptapod-publish")
		assert.Equal(t, header.Get(USERINFO_ID_HEADER), "17")
		assert.Equal(t, header.Get(USERINFO_USERNAME_HEADER), "testgr")
		assert.Equal(t, header.Get(USERINFO_NAME_HEADER), "Test GR")

		assert.Equal(t, header.Get(GL_REPOSITORY_HEADER), "project-23")
		// In normal cases the URL path should be the same as `GlProjectPath`
		// but whatever happens, the API Response is the source of truth
		assert.Equal(t, header.Get(PROJECT_NAMESPACE_FULL_PATH_HEADER), "path/to/my")
		assert.Equal(t, header.Get(PROJECT_PATH_HEADER), "repository")
		assert.Equal(t, header.Get(HG_NATIVE_HEADER), tc.native_expected)
	}
}

==> heptapod-rails-0.26.0.tar.gz: heptapod-rails-0.26.0/workhorse/internal/hg/hg-proxy_test.go <==
package hg

import (
	"net/http"
	"testing"

	"github.com/stretchr/testify/assert"
	"gitlab.com/gitlab-org/gitaly/v14/proto/go/gitalypb"

	"gitlab.com/gitlab-org/gitlab/workhorse/internal/api"
)

func TestAlterRequest(t *testing.T) {
	type testcase struct {
		native_input    bool
		no_git_input    bool
		native_expected string
		no_git_expected string
	}

	testcases := []testcase{
		{native_expected: "false", no_git_expected: "false"},
		{native_input: false, native_expected: "false", no_git_expected: "false"},
		{native_input: true, native_expected: "true", no_git_expected: "false"},
		{native_input: true, no_git_input: true, native_expected: "true", no_git_expected: "true"},
	}

	for _, tc := range testcases {
		api_resp := api.Response{
			GL_ID:                   "user-17",
			GL_USERNAME:             "testgr",
			GL_REPOSITORY:           "project-23",
			HG_ACCESS_LEVEL:         "publish",
			HEPTAPOD_USERINFO_EMAIL: "testgr@heptapod.test",
			HEPTAPOD_USERINFO_NAME:  "Test GR",
			HEPTAPOD_HG_NATIVE:      tc.native_input,
			HEPTAPOD_NO_GIT:         tc.no_git_input,
			Repository: gitalypb.Repository{
				StorageName:   "default",
				RelativePath:  "foo/bar.git",
				GlProjectPath: "path/to/my/repository",
			},
		}
		http_req, _ := http.NewRequest("GET",
			"http://heptapod.example/my/repo?cmd=capabilities", nil)
		alterRequest(http_req, &api_resp)

		// the path part of the backend request is derived from the Git
		// repo RelativePath
		assert.Equal(t, http_req.URL.Path, "foo/bar.hg")

		header := http_req.Header
		assert.Equal(t, header.Get(PERMISSION_HEADER), "heptapod-publish")
		assert.Equal(t, header.Get(USERINFO_ID_HEADER), "17")
		assert.Equal(t, header.Get(USERINFO_USERNAME_HEADER), "testgr")
		assert.Equal(t, header.Get(USERINFO_NAME_HEADER), "Test GR")

		assert.Equal(t, header.Get(GL_REPOSITORY_HEADER), "project-23")
		// In normal cases the URL path should be the same as `GlProjectPath`
		// but whatever happens, the API Response is the source of truth
		assert.Equal(t, header.Get(PROJECT_NAMESPACE_FULL_PATH_HEADER), "path/to/my")
		assert.Equal(t, header.Get(PROJECT_PATH_HEADER), "repository")
		assert.Equal(t, header.Get(HG_NATIVE_HEADER), tc.native_expected)
		assert.Equal(t, header.Get(NO_GIT_HEADER), tc.no_git_expected)
	}
}
